Documentation
¶
Overview ¶
Package exec provides an updater that executes an external command to update the repository.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExecUpdater ¶
type ExecUpdater struct {
Command string
Path string
Args []string
Stdout string
Stderr string
Timeout time.Duration
}
ExecUpdater is an updater that executes an external command to update the repository.
func NewUpdater ¶
func NewUpdater(params map[string]string) (*ExecUpdater, error)
NewUpdater builds a new exec updater from the given parameters
func (*ExecUpdater) Message ¶
func (u *ExecUpdater) Message() (title, body string)
Message returns the default title and body that should be used in the commits / pull requests
func (*ExecUpdater) String ¶
func (u *ExecUpdater) String() string
String returns a string representation of the updater
Click to show internal directories.
Click to hide internal directories.